==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/Storage/AmazonElasticBlockStoreVolumeGp3.md <==
# AmazonElasticBlockStoreVolumeGp3


```text
aws-20210730/Resource/Storage/AmazonElasticBlockStoreVolumeGp3
```

```text
include('aws-20210730/Resource/Storage/AmazonElasticBlockStoreVolumeGp3')
```



| Illustration | AmazonElasticBlockStoreVolumeGp3 | AmazonElasticBlockStoreVolumeGp3Card | AmazonElasticBlockStoreVolumeGp3Group |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Storage/AmazonElasticBlockStoreVolumeGp3.png) | ![illustration for AmazonElasticBlockStoreVolumeGp3](../../../aws-20210730/Resource/Storage/AmazonElasticBlockStoreVolumeGp3.Local.png) | ![illustration for AmazonElasticBlockStoreVolumeGp3Card](../../../aws-20210730/Resource/Storage/AmazonElasticBlockStoreVolumeGp3Card.Local.png) | ![illustration for AmazonElasticBlockStoreVolumeGp3Group](../../../aws-20210730/Resource/Storage/AmazonElasticBlockStoreVolumeGp3Group.Local.png) |




## AmazonElasticBlockStoreVolumeGp3

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticBlockStoreVolumeGp3
include('aws-20210730/Resource/Storage/AmazonElasticBlockStoreVolumeGp3')

' renders the element
AmazonElasticBlockStoreVolumeGp3('AmazonElasticBlockStoreVolumeGp3', 'Amazon Elastic Block Store Volume Gp3', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticBlockStoreVolumeGp3
include('aws-20210730/Resource/Storage/AmazonElasticBlockStoreVolumeGp3')

' renders the element
AmazonElasticBlockStoreVolumeGp3('AmazonElasticBlockStoreVolumeGp3', 'Amazon Elastic Block Store Volume Gp3', 'an optional tech label')
@enduml
```

## AmazonElasticBlockStoreVolumeGp3Card

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticBlockStoreVolumeGp3Card
include('aws-20210730/Resource/Storage/AmazonElasticBlockStoreVolumeGp3')

' renders the element
AmazonElasticBlockStoreVolumeGp3Card('AmazonElasticBlockStoreVolumeGp3Card', 'Amazon Elastic Block Store Volume Gp3 Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticBlockStoreVolumeGp3Card
include('aws-20210730/Resource/Storage/AmazonElasticBlockStoreVolumeGp3')

' renders the element
AmazonElasticBlockStoreVolumeGp3Card('AmazonElasticBlockStoreVolumeGp3Card', 'Amazon Elastic Block Store Volume Gp3 Card', 'an optional description')
@enduml
```

## AmazonElasticBlockStoreVolumeGp3Group

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticBlockStoreVolumeGp3Group
include('aws-20210730/Resource/Storage/AmazonElasticBlockStoreVolumeGp3')

' renders the element
AmazonElasticBlockStoreVolumeGp3Group('AmazonElasticBlockStoreVolumeGp3Group', 'Amazon Elastic Block Store Volume Gp3 Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticBlockStoreVolumeGp3Group
include('aws-20210730/Resource/Storage/AmazonElasticBlockStoreVolumeGp3')

' renders the element
AmazonElasticBlockStoreVolumeGp3Group('AmazonElasticBlockStoreVolumeGp3Group', 'Amazon Elastic Block Store Volume Gp3 Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-20210730/Resource/Storage/AmazonElasticBlockStoreVolumeGp3.md <==
# AmazonElasticBlockStoreVolumeGp3


```text
aws-20210730/Resource/Storage/AmazonElasticBlockStoreVolumeGp3
```

```text
include('aws-20210730/Resource/Storage/AmazonElasticBlockStoreVolumeGp3')
```



| Illustration | AmazonElasticBlockStoreVolumeGp3 | AmazonElasticBlockStoreVolumeGp3Card | AmazonElasticBlockStoreVolumeGp3Group |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Storage/AmazonElasticBlockStoreVolumeGp3.png) | ![illustration for AmazonElasticBlockStoreVolumeGp3](../../../aws-20210730/Resource/Storage/AmazonElasticBlockStoreVolumeGp3.Local.png) | ![illustration for AmazonElasticBlockStoreVolumeGp3Card](../../../aws-20210730/Resource/Storage/AmazonElasticBlockStoreVolumeGp3Card.Local.png) | ![illustration for AmazonElasticBlockStoreVolumeGp3Group](../../../aws-20210730/Resource/Storage/AmazonElasticBlockStoreVolumeGp3Group.Local.png) |




## AmazonElasticBlockStoreVolumeGp3

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticBlockStoreVolumeGp3
include('aws-20210730/Resource/Storage/AmazonElasticBlockStoreVolumeGp3')

' renders the element
AmazonElasticBlockStoreVolumeGp3('AmazonElasticBlockStoreVolumeGp3', 'Amazon Elastic Block Store Volume Gp3', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticBlockStoreVolumeGp3
include('aws-20210730/Resource/Storage/AmazonElasticBlockStoreVolumeGp3')

' renders the element
AmazonElasticBlockStoreVolumeGp3('AmazonElasticBlockStoreVolumeGp3', 'Amazon Elastic Block Store Volume Gp3', 'an optional tech label')
@enduml
```

## AmazonElasticBlockStoreVolumeGp3Card

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticBlockStoreVolumeGp3Card
include('aws-20210730/Resource/Storage/AmazonElasticBlockStoreVolumeGp3')

' renders the element
AmazonElasticBlockStoreVolumeGp3Card('AmazonElasticBlockStoreVolumeGp3Card', 'Amazon Elastic Block Store Volume Gp3 Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticBlockStoreVolumeGp3Card
include('aws-20210730/Resource/Storage/AmazonElasticBlockStoreVolumeGp3')

' renders the element
AmazonElasticBlockStoreVolumeGp3Card('AmazonElasticBlockStoreVolumeGp3Card', 'Amazon Elastic Block Store Volume Gp3 Card', 'an optional description')
@enduml
```

## AmazonElasticBlockStoreVolumeGp3Group

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticBlockStoreVolumeGp3Group
include('aws-20210730/Resource/Storage/AmazonElasticBlockStoreVolumeGp3')

' renders the element
AmazonElasticBlockStoreVolumeGp3Group('AmazonElasticBlockStoreVolumeGp3Group', 'Amazon Elastic Block Store Volume Gp3 Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticBlockStoreVolumeGp3Group
include('aws-20210730/Resource/Storage/AmazonElasticBlockStoreVolumeGp3')

' renders the element
AmazonElasticBlockStoreVolumeGp3Group('AmazonElasticBlockStoreVolumeGp3Group', 'Amazon Elastic Block Store Volume Gp3 Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
